﻿# Source paths
$sourcePaths = @(
    "HKCU:\SOFTWARE\Microsoft\Windows\CurrentVersion\Explorer\StartupApproved\Run"
	"HKCU:\SOFTWARE\Microsoft\Windows\CurrentVersion\Explorer\StartupApproved\Run32"
    "HKCU:\SOFTWARE\Microsoft\Windows\CurrentVersion\Explorer\StartupApproved\StartupFolder"
    "HKLM:\SOFTWARE\Microsoft\Windows\CurrentVersion\Explorer\StartupApproved\Run"
	"HKLM:\SOFTWARE\Microsoft\Windows\CurrentVersion\Explorer\StartupApproved\Run32"
	"HKLM:\SOFTWARE\Microsoft\Windows\CurrentVersion\Explorer\StartupApproved\StartupFolder"
)

# Target path
$targetPath = "HKLM:\SYSTEM\Startup"

# Counter for naming keys in target registry
$count = 0

# Iterate through source paths
foreach ($sourcePath in $sourcePaths) {
    # Check if source path exists
    if (Test-Path $sourcePath) {
        # Get the registry keys from source path
        $sourceKeys = Get-ItemProperty -Path $sourcePath

        # Create target registry path if it doesn't exist
        if (-not (Test-Path $targetPath)) {
            New-Item -Path $targetPath -Force
        }

        # Iterate through source keys
        foreach ($key in $sourceKeys.PSObject.Properties) {
            # Get name and data of the current source key
            $name = $key.Name
            $value = $key.Value

            # Check if the value is binary
            if ($value.GetType().Name -eq 'Byte[]') {
                # Get only the first digit from the binary value
                $data = $value -replace "^(\d).*", '$1'

                # Create new string value in target registry
                New-ItemProperty -Path $targetPath -Name $count -Value "$name;$data" -PropertyType String -Force
                $count++
            }
        }
    } else {
        Write-Host "Source registry path does not exist: $sourcePath"
    }
}
